% Fig 8-19
clear all ;% clear all variables
close all

%============== Define global variables ===================================================
%global BitRate DataLength ChannelNumber ChannelSpacing SampleRate t_range  
global BitRate Bits ChannelNumber ChannelSpacing SampleRate DataLength samplesperbit t_range f_sym

BitRate = 10e9;  
Bits2Power = 10;
Bits = 2^Bits2Power;
TimeWindow = Bits/BitRate;
ChannelNumber = 5;
ChannelSpacing = 100e9;   %[Hz]

SampleRateMargin = 5;  %MarginBandwidth = SampleRateMargin*ChannelSpacing
SampleRate = BitRate*SampleRateFactor(SampleRateMargin); %[Hz]
DataLength = TimeWindow*SampleRate;
samplesperbit = SampleRate/BitRate; % data number per bit

% time, optical frequency scale
t_range = 0:1/SampleRate:1/SampleRate*(DataLength-1);
f_sym = -.5/TimeWindow*(DataLength):1/TimeWindow:.5/TimeWindow*(DataLength-1);

%==========================================================================================

%=================== Define Simulation Blocks =============================================

%-------------- Laser Array -----------------------%
LaserNumber = ChannelNumber;
LaserSpacing = ChannelSpacing; %[Hz] Equal channel spacing

%--------------- Array: External Modulation ------------%
%=== Physical Parameters=======
PreSpaces = 2;  %number of leading zero bits
PostSpaces = 2; %number of trailing zero bits
RiseTime = 1/(4*BitRate); % 

UnmodulatedPower =  2e-3; %[W] % 
Linewidth = 0*50e6; %[Hz]
ModulationIndex = 1; %

%------------------------------------------------------------------------------%
[E_LaserArray,info_bits] = Array_TxModAmplitude_NRZ(UnmodulatedPower,Linewidth,...
          ModulationIndex,PreSpaces,PostSpaces,RiseTime,LaserNumber,LaserSpacing);
%------------------- Mux ----------------------------%                 
%E_Array_Muxed = WDM_Mux_Ideal(E_LaserArray);
E_Array_Muxed = WDM_Mux_Gaussian(E_LaserArray,2*BitRate,0);

% Define OpticalSpectrumAnalyzer Resolution Bandwidth
% Maximum Res_FilterWidth = BitRate/Bits
Res_FilterWidth = BitRate/32; 

OpticalSpectrumAnalyzer(E_Array_Muxed,Res_FilterWidth);
Pin2 = PowerMeter(E_Array_Muxed);
% Power calculated by 'OpticalSpectrumAnalyzer' and  by 'PowerMeter' should be equal to each other.

axis([-SampleRate/2 SampleRate/2 -50 10])

%-------------------------------------------------------------%
% ----------Add Noise to Control OSNR------------------------%   
OSNR_target = 30; %[dB] Target OSNR

NoisePower = (UnmodulatedPower/2)*10^(-OSNR_target/10);%UnmodulatedPower/2 = modulated power in NRZ 
NoisePowerDensity = NoisePower/Res_FilterWidth;
noise_add = NoiseWhiteG_Optical(NoisePowerDensity);

E_Array_MuxedNoise = E_Array_Muxed + noise_add;    

Paddn = OpticalSpectrumAnalyzer(E_Array_MuxedNoise,Res_FilterWidth)
Paddn2 = PowerMeter(E_Array_MuxedNoise)
% Power calculated by 'OpticalSpectrumAnalyzer' and  by 'PowerMeter' should be equal to each other.

axis([-SampleRate/2 SampleRate/2 -50 10])

%-------------------DeMux ----------------------------%                 
E_Array_DeMuxed = WDM_DeMux_Gaussian(E_Array_MuxedNoise,BitRate,0);

Pout = OpticalSpectrumAnalyzer(E_Array_DeMuxed,Res_FilterWidth)
Pout2 = PowerMeter(E_Array_DeMuxed)
% Power calculated by 'OpticalSpectrumAnalyzer' and  by 'PowerMeter' should be equal to each other.

axis([-SampleRate/2 SampleRate/2 -50 10])

