clear all ;% clear all variables
close all
%============== Define global variables ===================================================
global BitRate Bits TimeWindow SampleRate DataLength samplesperbit t_range f_sym Ref_Frequency

Ref_Frequency = 193.1e12; %[Hz] Reference optical frequency

BitRate = 10e9;  
Bits2Power = 7;
Bits = 2^Bits2Power;
TimeWindow = Bits/BitRate;
SampleRate = BitRate*2^10;
DataLength = TimeWindow*SampleRate;
samplesperbit = SampleRate/BitRate; % data number per bit

% time, optical frequency range
t_range = 0:1/SampleRate:1/SampleRate*(DataLength-1);
f_sym = SampleRate*(-DataLength/2:(DataLength/2-1))/DataLength; %

%==========================================================================================
%=================== Define Simulation Blocks =============================================
%------------- Transmitter -------------------%
df_ch = 100e9;

%Ch1: pump signal

P1 = 10e-3; %[W] 
Laser1 = LaserCW(P1);

PreSpaces = 2;  %number of leading zero bits
PostSpaces = 2; %number of trailing zero bits
info_bits = infobits_PRBS(PreSpaces,PostSpaces);

E_data1 = NRZCoder(info_bits);

ERiseTime = 1/4/BitRate; %  In the form of k/BitRate, k should be less than (1/2)*RZRatio if RZCoder used   
E_elec1 = RiseTimeAdjust(E_data1,ERiseTime);
df_carrier1 = exp(1i*2*pi*t_range*df_ch/2);
Ch1 = df_carrier1.*ModulatorAmplitude(Laser1,E_elec1);

%Ch2: probe signal
P2 = 10e-3; %[W] 
Laser2 = LaserCW(P2);
info_bits = infobits_PRBS(PreSpaces,PostSpaces);
E_data2 = NRZCoder(info_bits);
E_elec2 = RiseTimeAdjust(E_data2,ERiseTime);

df_carrier2 = exp(-1i*2*pi*t_range*df_ch/2);
Ch2 = df_carrier2.*ModulatorAmplitude(Laser2,E_elec2);

% Ideal Muxing
ch_signals = [Ch1;Ch2];
Ch_Muxed = sum(ch_signals);

pm = max(P1,P2);
ym = 10*log10(pm)+33;

OpticalSpectrumAnalyzer(Ch_Muxed);
axis([-6*df_ch 6*df_ch ym-60 ym])

%---------------- Transmission -------------------------------------
%=========== Fiber Parameters +++++++++++++++++========
Fiber_Length = 100e3; %[m]

%--------------------------------------------------------------------------
[yt yf] = SingleModeFiber(Ch_Muxed,Fiber_Length,0,0,0,2.6e-20,80e-12,0.005);

%---------------------------------------------------------

ch2_t = OpticalFilter_Bessel(Ch2,-df_ch/2, 2*BitRate,3); % Probe signal without fiber transmission
ch2_r = OpticalFilter_Bessel(yt,-df_ch/2, 2*BitRate,3); % probe signal after 100km transmission

%ch2_t = OpticalFilter_Rectangular(Ch2,-df_ch/2,3*BitRate);% Probe signal without fiber transmission
%ch2_r = OpticalFilter_Rectangular(yt,-df_ch/2,3*BitRate); % probe signal after 100km transmission

figure(2)
plot(t_range,abs(ch2_t).^2,'r',t_range,abs(ch2_r).^2)
title('CH2 signal (optical power)')
xlabel('[sec]'), ylabel('[W]')
legend('before transmission','after transmission')








